SystemSoundID enum
Default iOS system sound IDs
Values
- newMail → const SystemSoundID
-
1000
- mailSent → const SystemSoundID
-
1001
- voiceMailReceived → const SystemSoundID
-
1002
- receivedMessage → const SystemSoundID
-
1003
- sentMessage → const SystemSoundID
-
1004
- alarm → const SystemSoundID
-
1005
- lowPower → const SystemSoundID
-
1006
- smsReceived1 → const SystemSoundID
-
1007
- smsReceived2 → const SystemSoundID
-
1008
- smsReceived3 → const SystemSoundID
-
1009
- smsReceived4 → const SystemSoundID
-
1010
- smsReceivedVibrate → const SystemSoundID
-
1011
- smsReceived → const SystemSoundID
-
1012
- smsReceive5 → const SystemSoundID
-
1013
- smsReceive6 → const SystemSoundID
-
1014
- voicemail → const SystemSoundID
-
1015
- tweetSent → const SystemSoundID
-
1016
- anticipate → const SystemSoundID
-
1017-1019 待确认 1020
- bloom → const SystemSoundID
-
1021
- calypso → const SystemSoundID
-
1022
- chooChoo → const SystemSoundID
-
1023
- descent → const SystemSoundID
-
1024
- fanfare → const SystemSoundID
-
1025
- ladder → const SystemSoundID
-
1026
- minuet → const SystemSoundID
-
1027
- newsFlash → const SystemSoundID
-
1028
- noir → const SystemSoundID
-
1029
- sherwoodForest → const SystemSoundID
-
1030
- spell → const SystemSoundID
-
1031
- suspense → const SystemSoundID
-
1032
- telegraph → const SystemSoundID
-
1033
- tiptoes → const SystemSoundID
-
1034
- typewriters → const SystemSoundID
-
1035
- update → const SystemSoundID
-
1036
- ussd → const SystemSoundID
-
1037 - 1049 无 1050
- simToolkitCallDropped → const SystemSoundID
-
1052
- simToolkitGeneralBeep → const SystemSoundID
-
1052
- simToolkitNegativeACK → const SystemSoundID
-
1053
- simToolkitPositiveACK → const SystemSoundID
-
1054
- simToolkitSMS → const SystemSoundID
-
1055
- tink → const SystemSoundID
-
1056 无 1057
- webcamStart → const SystemSoundID
-
1060
- ctBusy → const SystemSoundID
-
1061 待确认 1070
- ctCongestion → const SystemSoundID
-
1071
- ctPathAck → const SystemSoundID
-
1072
- ctError → const SystemSoundID
-
1073
- ctCallWaiting → const SystemSoundID
-
1074
- ctKeytone2 → const SystemSoundID
-
1075
- lock → const SystemSoundID
-
1076 - 1099 无 1100,
- unlock → const SystemSoundID
-
1101
- failedUnlock → const SystemSoundID
-
1102
- tinkKeyPressed → const SystemSoundID
-
1103
- tock → const SystemSoundID
-
1104
- tock2 → const SystemSoundID
-
1105
- connectedToPower → const SystemSoundID
-
1106
- photoShutter → const SystemSoundID
-
1107 待确认 1108
- shake → const SystemSoundID
-
1109
- jblBegin → const SystemSoundID
-
1110
- jblConfirm → const SystemSoundID
-
1111
- jblCancel → const SystemSoundID
-
1112
- beginRecord → const SystemSoundID
-
1113
- endRecord → const SystemSoundID
-
1114
- jblAmbiguous → const SystemSoundID
-
1115
- jblNoMatch → const SystemSoundID
-
1116
- beginVideoRecord → const SystemSoundID
-
1117
- endVideoRecord → const SystemSoundID
-
1118
- vcInvitationAccepted → const SystemSoundID
-
1119-1149 待确认 1150
- vcRinging → const SystemSoundID
-
1151
- vcEnded → const SystemSoundID
-
1152
- ctCallWaiting2 → const SystemSoundID
-
1153
- vcRinging2 → const SystemSoundID
-
1154
- dtmf0 → const SystemSoundID
-
1155 -1199 待确认 1200
- dtmf1 → const SystemSoundID
-
1201
- dtmf2 → const SystemSoundID
-
1202
- dtmf3 → const SystemSoundID
-
1203
- dtmf4 → const SystemSoundID
-
1204
- dtmf5 → const SystemSoundID
-
1205
- dtmf6 → const SystemSoundID
-
1206
- dtmf7 → const SystemSoundID
-
1207
- dtmf8 → const SystemSoundID
-
1208
- dtmf9 → const SystemSoundID
-
1209
- dtmfStar → const SystemSoundID
-
1210
- dtmfPound → const SystemSoundID
-
1211
- longLowShortHigh → const SystemSoundID
-
1212 - 1252 无 1253 待确认 1254
- shortDoubleHigh → const SystemSoundID
-
1255
- shortLowHigh → const SystemSoundID
-
1256
- shortDoubleLow → const SystemSoundID
-
1257
- shortDoubleLow2 → const SystemSoundID
-
1258
- middle9ShortDoubleLow → const SystemSoundID
-
1259
- voicemail2 → const SystemSoundID
-
1260 - 1299 待确认 1300
- receivedMessage2 → const SystemSoundID
-
1301
- newMail2 → const SystemSoundID
-
1302
- mailSent2 → const SystemSoundID
-
1303
- alarm2 → const SystemSoundID
-
1304
- lock2 → const SystemSoundID
-
1305
- tock3 → const SystemSoundID
-
1306
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Get the integer value for the system sound ID
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SystemSoundID> - A constant List of the values in this enum, in order of their declaration.